pub struct AddBalanceLiquidity {Show 16 fields
pub pool: Pubkey,
pub lp_mint: Pubkey,
pub user_pool_lp: Pubkey,
pub a_vault_lp: Pubkey,
pub b_vault_lp: Pubkey,
pub a_vault: Pubkey,
pub b_vault: Pubkey,
pub a_vault_lp_mint: Pubkey,
pub b_vault_lp_mint: Pubkey,
pub a_token_vault: Pubkey,
pub b_token_vault: Pubkey,
pub user_a_token: Pubkey,
pub user_b_token: Pubkey,
pub user: Pubkey,
pub vault_program: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for AddBalanceLiquidity.
Fields
pool: Pubkeylp_mint: Pubkeyuser_pool_lp: Pubkeya_vault_lp: Pubkeyb_vault_lp: Pubkeya_vault: Pubkeyb_vault: Pubkeya_vault_lp_mint: Pubkeyb_vault_lp_mint: Pubkeya_token_vault: Pubkeyb_token_vault: Pubkeyuser_a_token: Pubkeyuser_b_token: Pubkeyuser: Pubkeyvault_program: Pubkeytoken_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for AddBalanceLiquiditywhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddBalanceLiquiditywhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for AddBalanceLiquidity
impl ToAccountMetas for AddBalanceLiquidity
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for AddBalanceLiquidity
impl RefUnwindSafe for AddBalanceLiquidity
impl Send for AddBalanceLiquidity
impl Sync for AddBalanceLiquidity
impl Unpin for AddBalanceLiquidity
impl UnwindSafe for AddBalanceLiquidity