pub struct InitializePermissionlessPool {Show 26 fields
pub pool: Pubkey,
pub lp_mint: Pubkey,
pub token_a_mint: Pubkey,
pub token_b_mint: Pubkey,
pub a_vault: Pubkey,
pub b_vault: Pubkey,
pub a_token_vault: Pubkey,
pub b_token_vault: Pubkey,
pub a_vault_lp_mint: Pubkey,
pub b_vault_lp_mint: Pubkey,
pub a_vault_lp: Pubkey,
pub b_vault_lp: Pubkey,
pub payer_token_a: Pubkey,
pub payer_token_b: Pubkey,
pub payer_pool_lp: Pubkey,
pub protocol_token_a_fee: Pubkey,
pub protocol_token_b_fee: Pubkey,
pub payer: Pubkey,
pub fee_owner: Pubkey,
pub rent: Pubkey,
pub mint_metadata: Pubkey,
pub metadata_program: Pubkey,
pub vault_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for InitializePermissionlessPool.
Fields
pool: Pubkeylp_mint: Pubkeytoken_a_mint: Pubkeytoken_b_mint: Pubkeya_vault: Pubkeyb_vault: Pubkeya_token_vault: Pubkeyb_token_vault: Pubkeya_vault_lp_mint: Pubkeyb_vault_lp_mint: Pubkeya_vault_lp: Pubkeyb_vault_lp: Pubkeypayer_token_a: Pubkeypayer_token_b: Pubkeypayer_pool_lp: Pubkeyprotocol_token_a_fee: Pubkeyprotocol_token_b_fee: Pubkeypayer: Pubkeyfee_owner: Pubkeyrent: Pubkeymint_metadata: Pubkeymetadata_program: Pubkeyvault_program: Pubkeytoken_program: Pubkeyassociated_token_program: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for InitializePermissionlessPoolwhere
Pubkey: BorshSerialize,
impl BorshSerialize for InitializePermissionlessPoolwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for InitializePermissionlessPool
impl ToAccountMetas for InitializePermissionlessPool
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for InitializePermissionlessPool
impl RefUnwindSafe for InitializePermissionlessPool
impl Send for InitializePermissionlessPool
impl Sync for InitializePermissionlessPool
impl Unpin for InitializePermissionlessPool
impl UnwindSafe for InitializePermissionlessPool