pub struct OverrideCurveParam {
pub _curve_type: CurveType,
}Expand description
Instruction.
Fields
_curve_type: CurveTypeTrait Implementations
Sourceimpl BorshDeserialize for OverrideCurveParamwhere
CurveType: BorshDeserialize,
impl BorshDeserialize for OverrideCurveParamwhere
CurveType: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for OverrideCurveParamwhere
CurveType: BorshSerialize,
impl BorshSerialize for OverrideCurveParamwhere
CurveType: BorshSerialize,
Sourceimpl Discriminator for OverrideCurveParam
impl Discriminator for OverrideCurveParam
const DISCRIMINATOR: [u8; 8]
fn discriminator() -> [u8; 8]
Sourceimpl InstructionData for OverrideCurveParam
impl InstructionData for OverrideCurveParam